Crate kcr_hive_openshift_io

Crate kcr_hive_openshift_io 

This crate contains kube-rs compatible bindings for Kubernetes custom resources for the hive.openshift.io group. Each binding is generated with kopium, updated and released weekly.

Available Custom Resources

hive.openshift.io/v1

  • Checkpoint
  • ClusterClaim
  • ClusterDeploymentCustomization
  • ClusterDeployment
  • ClusterDeprovision
  • ClusterImageSet
  • ClusterPool
  • ClusterProvision
  • ClusterRelocate
  • ClusterState
  • DNSZone
  • HiveConfig
  • MachinePoolNameLease
  • MachinePool
  • SelectorSyncIdentityProvider
  • SelectorSyncSet
  • SyncIdentityProvider
  • SyncSet

Modules

v1